@@ -23,6 +23,9 @@ from pm4py.objects.log.obj import EventLog, Trace
 from pm4py.util import constants, xes_constants, exec_utils
 from pm4py.util import variants_util
 from pm4py.objects.petri_net.utils import align_utils
+from pm4py.objects.log.obj import EventLog, Trace
+from typing import Optional, Dict, Any, Union, Tuple
+from pm4py.util import typing
 
 
 class Parameters(Enum):
@@ -54,7 +57,7 @@ POSITION_IS_MM = 8
 POSITION_PREV = 9
 
 
-def apply(obj, dfg, sa, ea, parameters=None):
+def apply(obj: Union[EventLog, Trace], dfg: Dict[Tuple[str, str], int], sa: Dict[str, int], ea: Dict[str, int], parameters: Optional[Dict[Union[str, Parameters], Any]] = None) -> Union[typing.AlignmentResult, typing.ListAlignments]:
     """
     Applies the alignment algorithm provided a log/trace object, and a *connected* DFG
 
@@ -129,12 +132,20 @@ def apply_log(log, dfg, sa, ea, parameters=None):
     aligned_traces = []
     align_dict = {}
 
+    al_empty_cost = __apply_list_activities([], dfg, sa, ea, parameters=parameters)["cost"]
+
     for trace in log:
         trace_act = tuple(x[activity_key] for x in trace)
         if trace_act in align_dict:
             aligned_traces.append(align_dict[trace_act])
         else:
+            log_move_cost_function = exec_utils.get_param_value(Parameters.LOG_MOVE_COST_FUNCTION, parameters,
+                                                                {x: align_utils.STD_MODEL_LOG_MOVE_COST for x in
+                                                                 trace_act})
+            trace_bwc_cost = sum(log_move_cost_function[x] for x in trace_act)
             al_tr = __apply_list_activities(trace_act, dfg, sa, ea, parameters=parameters)
+            al_tr["fitness"] = 1.0 - al_tr["cost"] / (al_empty_cost + trace_bwc_cost)
+            al_tr["bwc"] = al_empty_cost + trace_bwc_cost
             align_dict[trace_act] = al_tr
             aligned_traces.append(align_dict[trace_act])
 
