@@ -14,7 +14,8 @@
     You should have received a copy of the GNU General Public License
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
-from typing import Tuple, List, Set, Counter
+
+from typing import Tuple, List, Set, Dict
 
 Cut = List[Set[str]]
-DFG = Counter[Tuple[str, str]]
+DFG = Dict[Tuple[str, str], int]
