@@ -27,16 +27,19 @@ from pm4py.statistics.attributes.log.get import get_attribute_values
 from pm4py.util import exec_utils
 from pm4py.util import xes_constants as xes
 from pm4py.util.constants import PARAMETER_CONSTANT_ATTRIBUTE_KEY, PARAMETER_CONSTANT_ACTIVITY_KEY
-from pm4py.util.constants import PARAMETER_CONSTANT_CASEID_KEY
+from pm4py.util.constants import PARAMETER_CONSTANT_CASEID_KEY, PARAMETER_KEY_CASE_GLUE
 from pm4py.util.xes_constants import DEFAULT_NAME_KEY
 from copy import copy
 import deprecation
+from typing import Optional, Dict, Any, Union, Tuple, List
+from pm4py.objects.log.obj import EventLog, EventStream
 
 
 class Parameters(Enum):
     ATTRIBUTE_KEY = PARAMETER_CONSTANT_ATTRIBUTE_KEY
     ACTIVITY_KEY = PARAMETER_CONSTANT_ACTIVITY_KEY
     CASE_ID_KEY = PARAMETER_CONSTANT_CASEID_KEY
+    PARAMETER_KEY_CASE_GLUE = PARAMETER_KEY_CASE_GLUE
     DECREASING_FACTOR = "decreasingFactor"
     POSITIVE = "positive"
     STREAM_FILTER_KEY1 = "stream_filter_key1"
@@ -45,7 +48,7 @@ class Parameters(Enum):
     STREAM_FILTER_VALUE2 = "stream_filter_value2"
 
 
-def apply_numeric(log, int1, int2, parameters=None):
+def apply_numeric(log: EventLog, int1: float, int2: float, parameters: Optional[Dict[Union[str, Parameters], Any]] = None) -> EventLog:
     """
     Apply a filter on cases (numerical filter)
 
@@ -71,6 +74,7 @@ def apply_numeric(log, int1, int2, parameters=None):
     attribute_key = exec_utils.get_param_value(Parameters.ATTRIBUTE_KEY, parameters, DEFAULT_NAME_KEY)
     case_key = exec_utils.get_param_value(Parameters.CASE_ID_KEY, parameters, xes.DEFAULT_TRACEID_KEY)
     positive = exec_utils.get_param_value(Parameters.POSITIVE, parameters, True)
+    case_attribute_prefix = exec_utils.get_param_value(Parameters.PARAMETER_KEY_CASE_GLUE, parameters, constants.CASE_ATTRIBUTE_PREFIX)
     # stream_filter_key is helpful to filter on cases containing an event with an attribute
     # in the specified value set, but such events shall have an activity in particular.
 
@@ -104,7 +108,7 @@ def apply_numeric(log, int1, int2, parameters=None):
             attributes=log.attributes, extensions=log.extensions, classifiers=log.classifiers,
             omni_present=log.omni_present, properties=log.properties)
 
-    all_cases_ids = set(x["case:" + case_key] for x in stream)
+    all_cases_ids = set(x[case_attribute_prefix + case_key] for x in stream)
 
     filtered_log = EventLog(list(), attributes=log.attributes, extensions=log.extensions, classifiers=log.classifiers,
                             omni_present=log.omni_present, properties=log.properties)
@@ -116,7 +120,7 @@ def apply_numeric(log, int1, int2, parameters=None):
     return filtered_log
 
 
-def apply_numeric_events(log, int1, int2, parameters=None):
+def apply_numeric_events(log: EventLog, int1: float, int2: float, parameters: Optional[Dict[Union[str, Parameters], Any]] = None) -> EventLog:
     """
     Apply a filter on events (numerical filter)
 
@@ -155,12 +159,12 @@ def apply_numeric_events(log, int1, int2, parameters=None):
             list(filter(lambda x: attribute_key in x and (x[attribute_key] < int1 or x[attribute_key] > int2), stream)),
             attributes=log.attributes, extensions=log.extensions, classifiers=log.classifiers,
             omni_present=log.omni_present, properties=log.properties)
-    filtered_log = log_converter.apply(stream)
+    filtered_log = log_converter.apply(stream, parameters=conversion_parameters)
 
     return filtered_log
 
 
-def apply_events(log, values, parameters=None):
+def apply_events(log: EventLog, values: List[str], parameters: Optional[Dict[Union[str, Parameters], Any]] = None) -> EventLog:
     """
     Filter log by keeping only events with an attribute value that belongs to the provided values list
 
@@ -199,12 +203,12 @@ def apply_events(log, values, parameters=None):
                              extensions=log.extensions, classifiers=log.classifiers,
                              omni_present=log.omni_present, properties=log.properties)
 
-    filtered_log = log_converter.apply(stream)
+    filtered_log = log_converter.apply(stream, parameters=conversion_parameters)
 
     return filtered_log
 
 
-def apply(log, values, parameters=None):
+def apply(log: EventLog, values: List[str], parameters: Optional[Dict[Union[str, Parameters], Any]] = None) -> EventLog:
     """
     Filter log by keeping only traces that has/has not events with an attribute value that belongs to the provided
     values list
@@ -254,7 +258,7 @@ def apply(log, values, parameters=None):
     return filtered_log
 
 
-def apply_trace_attribute(log, values, parameters=None):
+def apply_trace_attribute(log: EventLog, values: List[str], parameters: Optional[Dict[Union[str, Parameters], Any]] = None) -> EventLog:
     """
     Filter a log on the trace attribute values
 
@@ -293,7 +297,7 @@ def apply_trace_attribute(log, values, parameters=None):
     return filtered_log
 
 
-def filter_log_on_max_no_activities(log, max_no_activities=25, parameters=None):
+def filter_log_on_max_no_activities(log: EventLog, max_no_activities : int = 25, parameters: Optional[Dict[Union[str, Parameters], Any]] = None) -> EventLog:
     """
     Filter a log on a maximum number of activities
 
