@@ -46,12 +46,14 @@ class Parameters(Enum):
     DEFAULT_NOT_PRESENT = "default_not_present"
     ENABLE_ALL_EXTRA_FEATURES = "enable_all_extra_features"
     ENABLE_CASE_DURATION = "enable_case_duration"
+    ADD_CASE_IDENTIFIER_COLUMN = "add_case_identifier_column"
     ENABLE_TIMES_FROM_FIRST_OCCURRENCE = "enable_times_from_first_occurrence"
     ENABLE_TIMES_FROM_LAST_OCCURRENCE = "enable_times_from_last_occurrence"
     ENABLE_DIRECT_PATHS_TIMES_LAST_OCC = "enable_direct_paths_times_last_occ"
     ENABLE_INDIRECT_PATHS_TIMES_LAST_OCC = "enable_indirect_paths_times_last_occ"
     ENABLE_WORK_IN_PROGRESS = "enable_work_in_progress"
     ENABLE_RESOURCE_WORKLOAD = "enable_resource_workload"
+    ENABLE_FIRST_LAST_ACTIVITY_INDEX = "enable_first_last_activity_index"
 
 
 def resource_workload(log: EventLog, parameters: Optional[Dict[Union[str, Parameters], Any]] = None) -> Tuple[Any, List[str]]:
@@ -399,6 +401,64 @@ def times_from_last_occurrence_activity_case(log: EventLog, parameters: Optional
     return data, feature_names
 
 
+def first_last_activity_index_trace(log: EventLog, parameters: Optional[Dict[Union[str, Parameters], Any]] = None) -> Tuple[Any, List[str]]:
+    """
+    Consider as features the first and the last index of an activity inside a case
+
+    Parameters
+    ------------------
+    log
+        Event log
+    parameters
+        Parameters, including:
+        - Parameters.ACTIVITY_KEY => the attribute to use as activity
+        - Parameters.DEFAULT_NOT_PRESENT => the replacement value for activities that are not present for the specific case
+
+    Returns
+    -----------------
+    data
+        Numeric value of the features
+    feature_names
+        Names of the features
+    """
+    if parameters is None:
+        parameters = {}
+
+    activity_key = exec_utils.get_param_value(Parameters.ACTIVITY_KEY, parameters, xes_constants.DEFAULT_NAME_KEY)
+    default_not_present = exec_utils.get_param_value(Parameters.DEFAULT_NOT_PRESENT, parameters, -1)
+
+    activities_log = set()
+    for trace in log:
+        for event in trace:
+            activities_log.add(event[activity_key])
+    activities_log = sorted(list(activities_log))
+
+    data = []
+    feature_names = []
+    for act in activities_log:
+        feature_names.append("firstIndexAct@@"+act)
+        feature_names.append("lastIndexAct@@"+act)
+    for trace in log:
+        data.append([])
+
+        first_occ = {}
+        last_occ = {}
+        for index, event in enumerate(trace):
+            act = event[activity_key]
+            last_occ[act] = index
+            if act not in first_occ:
+                first_occ[act] = index
+        for act in activities_log:
+            if act not in first_occ:
+                data[-1].append(default_not_present)
+                data[-1].append(default_not_present)
+            else:
+                data[-1].append(first_occ[act])
+                data[-1].append(last_occ[act])
+
+    return data, feature_names
+
+
 def case_duration(log: EventLog, parameters: Optional[Dict[Union[str, Parameters], Any]] = None) -> Tuple[Any, List[str]]:
     """
     Calculates for each case, the case duration (and adds it as a feature)
@@ -943,6 +1003,7 @@ def apply(log: EventLog, parameters: Optional[Dict[Union[str, Parameters], Any]]
         - ENABLE_CASE_DURATION => enables the case duration as additional feature
         - ENABLE_TIMES_FROM_FIRST_OCCURRENCE => enables the addition of the times from start of the case, to the end
         of the case, from the first occurrence of an activity of a case
+        - ADD_CASE_IDENTIFIER_COLUMN => adds the case identifier (string) as column of the feature table (default: False)
         - ENABLE_TIMES_FROM_LAST_OCCURRENCE => enables the addition of the times from start of the case, to the end
         of the case, from the last occurrence of an activity of a case
         - ENABLE_DIRECT_PATHS_TIMES_LAST_OCC => add the duration of the last occurrence of a directed (i, i+1) path
@@ -951,6 +1012,7 @@ def apply(log: EventLog, parameters: Optional[Dict[Union[str, Parameters], Any]]
         in the case as feature
         - ENABLE_WORK_IN_PROGRESS => enables the work in progress (number of concurrent cases) as a feature
         - ENABLE_RESOURCE_WORKLOAD => enables the resource workload as a feature
+        - ENABLE_FIRST_LAST_ACTIVITY_INDEX => enables the insertion of the indexes of the activities as features
 
     Returns
     -------------
@@ -969,6 +1031,8 @@ def apply(log: EventLog, parameters: Optional[Dict[Union[str, Parameters], Any]]
     str_evsucc_attr = exec_utils.get_param_value(Parameters.STR_EVSUCC_ATTRIBUTES, parameters, None)
     feature_names = exec_utils.get_param_value(Parameters.FEATURE_NAMES, parameters, None)
 
+    at_least_one_provided = (str_tr_attr is not None) or (num_tr_attr is not None) or (str_ev_attr is not None) or (num_ev_attr is not None)
+
     if str_tr_attr is None:
         str_tr_attr = []
 
@@ -993,6 +1057,8 @@ def apply(log: EventLog, parameters: Optional[Dict[Union[str, Parameters], Any]]
         return fea_df, feature_names
     else:
         enable_all = exec_utils.get_param_value(Parameters.ENABLE_ALL_EXTRA_FEATURES, parameters, False)
+        case_id_key = exec_utils.get_param_value(Parameters.CASE_ID_KEY, parameters, xes_constants.DEFAULT_TRACEID_KEY)
+        add_case_identifier_column = exec_utils.get_param_value(Parameters.ADD_CASE_IDENTIFIER_COLUMN, parameters, False)
         enable_case_duration = exec_utils.get_param_value(Parameters.ENABLE_CASE_DURATION, parameters, enable_all)
         enable_times_from_first_occ = exec_utils.get_param_value(Parameters.ENABLE_TIMES_FROM_FIRST_OCCURRENCE,
                                                                  parameters, enable_all)
@@ -1004,15 +1070,22 @@ def apply(log: EventLog, parameters: Optional[Dict[Union[str, Parameters], Any]]
             Parameters.ENABLE_INDIRECT_PATHS_TIMES_LAST_OCC, parameters, enable_all)
         enable_work_in_progress = exec_utils.get_param_value(Parameters.ENABLE_WORK_IN_PROGRESS, parameters, enable_all)
         enable_resource_workload = exec_utils.get_param_value(Parameters.ENABLE_RESOURCE_WORKLOAD, parameters, enable_all)
+        enable_first_last_activity_index = exec_utils.get_param_value(Parameters.ENABLE_FIRST_LAST_ACTIVITY_INDEX, parameters, enable_all)
 
         log = converter.apply(log, parameters=parameters)
-        if str_tr_attr or num_tr_attr or str_ev_attr or num_ev_attr:
+        if at_least_one_provided:
             datas, features_namess = get_representation(log, str_tr_attr, str_ev_attr, num_tr_attr, num_ev_attr,
                                       str_evsucc_attr=str_evsucc_attr, feature_names=feature_names)
         else:
             datas, features_namess = get_default_representation(log, parameters=parameters)
 
+        if add_case_identifier_column:
+            for i in range(len(datas)):
+                datas[i] = [log[i].attributes[case_id_key]] + datas[i]
+            features_namess = ["@@case_id_column"] + features_namess
+
         # add additional features
+
         if enable_case_duration:
             data, features_names = case_duration(log, parameters=parameters)
             for i in range(len(datas)):
@@ -1055,4 +1128,10 @@ def apply(log: EventLog, parameters: Optional[Dict[Union[str, Parameters], Any]]
                 datas[i] = datas[i] + data[i]
             features_namess = features_namess + features_names
 
+        if enable_first_last_activity_index:
+            data, features_names = first_last_activity_index_trace(log, parameters=parameters)
+            for i in range(len(datas)):
+                datas[i] = datas[i] + data[i]
+            features_namess = features_namess + features_names
+
         return datas, features_namess
