@@ -24,8 +24,8 @@ from pm4py.objects.log.obj import EventStream
 from pm4py.util import constants
 from pm4py.util import exec_utils
 from pm4py.util import points_subset
-from pm4py.util import xes_constants
-from pm4py.util.vers_checker import check_pandas_ge_024
+from pm4py.util import xes_constants, pandas_utils
+
 
 LEGACY_PARQUET_TP_REPLACER = "AAA"
 LEGACY_PARQUET_CASECONCEPTNAME = "caseAAAconceptAAAname"
@@ -34,10 +34,18 @@ LEGACY_PARQUET_CASECONCEPTNAME = "caseAAAconceptAAAname"
 class Parameters(Enum):
     PARTITION_COLUMN = "partition_column"
     CASE_ID_KEY = constants.PARAMETER_CONSTANT_CASEID_KEY
+    CASE_PREFIX = constants.CASE_ATTRIBUTE_PREFIX
+    CASE_ATTRIBUTES = "case_attributes"
     MANDATORY_ATTRIBUTES = "mandatory_attributes"
     MAX_NO_CASES = "max_no_cases"
     MIN_DIFFERENT_OCC_STR_ATTR = 5
     MAX_DIFFERENT_OCC_STR_ATTR = 50
+    TIMESTAMP_KEY = constants.PARAMETER_CONSTANT_TIMESTAMP_KEY
+    ACTIVITY_KEY = constants.PARAMETER_CONSTANT_ACTIVITY_KEY
+    PARAM_ARTIFICIAL_START_ACTIVITY = constants.PARAM_ARTIFICIAL_START_ACTIVITY
+    PARAM_ARTIFICIAL_END_ACTIVITY = constants.PARAM_ARTIFICIAL_END_ACTIVITY
+    INDEX_KEY = "index_key"
+    USE_EXTREMES_TIMESTAMP = "use_extremes_timestamp"
 
 
 def insert_partitioning(df, num_partitions, parameters=None):
@@ -220,10 +228,13 @@ def automatic_feature_selection_df(df, parameters=None):
         parameters = {}
 
     case_id_key = exec_utils.get_param_value(Parameters.CASE_ID_KEY, parameters, constants.CASE_CONCEPT_NAME)
+    timestamp_key = exec_utils.get_param_value(Parameters.TIMESTAMP_KEY, parameters, xes_constants.DEFAULT_TIMESTAMP_KEY)
+    activity_key = exec_utils.get_param_value(Parameters.ACTIVITY_KEY, parameters, xes_constants.DEFAULT_NAME_KEY)
+
     mandatory_attributes = exec_utils.get_param_value(Parameters.MANDATORY_ATTRIBUTES, parameters,
                                                       set(df.columns).intersection(
-                                                          {constants.CASE_CONCEPT_NAME, xes_constants.DEFAULT_NAME_KEY,
-                                                           xes_constants.DEFAULT_TIMESTAMP_KEY}))
+                                                          {case_id_key, activity_key,
+                                                           timestamp_key}))
 
     min_different_occ_str_attr = exec_utils.get_param_value(Parameters.MIN_DIFFERENT_OCC_STR_ATTR, parameters, 5)
     max_different_occ_str_attr = exec_utils.get_param_value(Parameters.MAX_DIFFERENT_OCC_STR_ATTR, parameters, 50)
@@ -370,9 +381,115 @@ def automatic_feature_extraction_df(df: pd.DataFrame, parameters: Optional[Dict[
     if parameters is None:
         parameters = {}
 
+    case_id_key = exec_utils.get_param_value(Parameters.CASE_ID_KEY, parameters, constants.CASE_CONCEPT_NAME)
+    timestamp_key = exec_utils.get_param_value(Parameters.TIMESTAMP_KEY, parameters, xes_constants.DEFAULT_TIMESTAMP_KEY)
+
     fea_sel_df = automatic_feature_selection_df(df, parameters=parameters)
     columns = set(fea_sel_df.columns)
-    columns.remove(constants.CASE_CONCEPT_NAME)
-    columns.remove(xes_constants.DEFAULT_TIMESTAMP_KEY)
 
-    return get_features_df(fea_sel_df, columns, parameters=parameters)
+    if case_id_key in columns:
+        columns.remove(case_id_key)
+
+    if timestamp_key in columns:
+        columns.remove(timestamp_key)
+
+    return get_features_df(fea_sel_df, list(columns), parameters=parameters)
+
+
+def insert_artificial_start_end(df0: pd.DataFrame, parameters: Optional[Dict[Any, Any]] = None) -> pd.DataFrame:
+    """
+    Inserts the artificial start/end activities in a Pandas dataframe
+
+    Parameters
+    ------------------
+    df0
+        Dataframe
+    parameters
+        Parameters of the algorithm, including:
+        - Parameters.CASE_ID_KEY: the case identifier
+        - Parameters.TIMESTAMP_KEY: the timestamp
+        - Parameters.ACTIVITY_KEY: the activity
+
+    Returns
+    -----------------
+    enriched_df
+        Dataframe with artificial start/end activities
+    """
+    if parameters is None:
+        parameters = {}
+
+    case_id_key = exec_utils.get_param_value(Parameters.CASE_ID_KEY, parameters, constants.CASE_CONCEPT_NAME)
+    timestamp_key = exec_utils.get_param_value(Parameters.TIMESTAMP_KEY, parameters, xes_constants.DEFAULT_TIMESTAMP_KEY)
+    activity_key = exec_utils.get_param_value(Parameters.ACTIVITY_KEY, parameters, xes_constants.DEFAULT_NAME_KEY)
+    use_extremes_timestamp = exec_utils.get_param_value(Parameters.USE_EXTREMES_TIMESTAMP, parameters, False)
+
+    artificial_start_activity = exec_utils.get_param_value(Parameters.PARAM_ARTIFICIAL_START_ACTIVITY, parameters, constants.DEFAULT_ARTIFICIAL_START_ACTIVITY)
+    artificial_end_activity = exec_utils.get_param_value(Parameters.PARAM_ARTIFICIAL_END_ACTIVITY, parameters, constants.DEFAULT_ARTIFICIAL_END_ACTIVITY)
+
+    index_key = exec_utils.get_param_value(Parameters.INDEX_KEY, parameters, constants.DEFAULT_INDEX_KEY)
+
+    df = df0.copy()
+    df = pandas_utils.insert_index(df, index_key)
+    df = df.sort_values([case_id_key, timestamp_key, index_key])
+
+    start_df = df[[case_id_key, timestamp_key]].groupby(case_id_key).first().reset_index()
+    end_df = df[[case_id_key, timestamp_key]].groupby(case_id_key).last().reset_index()
+    # stability trick: remove 1ms from the artificial start activity timestamp, add 1ms to the artificial end activity timestamp
+    if use_extremes_timestamp:
+        start_df[timestamp_key] = pd.Timestamp.min
+        end_df[timestamp_key] = pd.Timestamp.max
+        start_df[timestamp_key] = start_df[timestamp_key].dt.tz_localize("utc")
+        end_df[timestamp_key] = end_df[timestamp_key].dt.tz_localize("utc")
+    else:
+        start_df[timestamp_key] = start_df[timestamp_key] - pd.Timedelta("1 ms")
+        end_df[timestamp_key] = end_df[timestamp_key] + pd.Timedelta("1 ms")
+
+    start_df[activity_key] = artificial_start_activity
+    end_df[activity_key] = artificial_end_activity
+
+    df = pd.concat([start_df, df, end_df])
+    df = pandas_utils.insert_index(df, index_key)
+    df = df.sort_values([case_id_key, timestamp_key, index_key])
+
+    df.attrs = df0.attrs
+
+    return df
+
+
+def dataframe_to_activity_case_table(df: pd.DataFrame, parameters: Optional[Dict[Any, Any]] = None):
+    """
+    Transforms a Pandas dataframe into:
+    - an "activity" table, containing the events and their attributes
+    - a "case" table, containing the cases and their attributes
+
+    Parameters
+    --------------
+    df
+        Dataframe
+    parameters
+        Parameters of the algorithm that should be used, including:
+        - Parameters.CASE_ID_KEY => the column to be used as case ID (shall be included both in the activity table and the case table)
+        - Parameters.CASE_PREFIX => if a list of attributes at the case level is not provided, then all the ones of the dataframe
+                                    starting with one of these are considered.
+        - Parameters.CASE_ATTRIBUTES => the attributes of the dataframe to be used as case columns
+
+    Returns
+    ---------------
+    activity_table
+        Activity table
+    case_table
+        Case table
+    """
+    if parameters is None:
+        parameters = {}
+
+    case_id_key = exec_utils.get_param_value(Parameters.CASE_ID_KEY, parameters, constants.CASE_CONCEPT_NAME)
+    case_id_prefix = exec_utils.get_param_value(Parameters.CASE_PREFIX, parameters, constants.CASE_ATTRIBUTE_PREFIX)
+
+    case_attributes = exec_utils.get_param_value(Parameters.CASE_ATTRIBUTES, parameters, set([x for x in df.columns if x.startswith(case_id_prefix)]))
+    event_attributes = set([x for x in df.columns if x not in case_attributes])
+
+    activity_table = df[event_attributes.union({case_id_key})]
+    case_table = df[case_attributes.union({case_id_key})].groupby(case_id_key).first().reset_index()
+
+    return activity_table, case_table
