@@ -370,7 +370,8 @@ def find_min_max_arc_performance(statistics, aggregation_measure):
     return min_performance, max_performance
 
 
-def aggregate_statistics(statistics, measure="frequency", aggregation_measure=None):
+def aggregate_statistics(statistics, measure="frequency", aggregation_measure=None,
+                         stat_locale: dict = {}):
     """
     Gets aggregated statistics
 
@@ -382,7 +383,9 @@ def aggregate_statistics(statistics, measure="frequency", aggregation_measure=No
         Desidered view on data (frequency or performance)
     aggregation_measure
         Aggregation measure (e.g. mean, min) to use
-
+    stat_locale
+        Dict to locale the stat strings
+    
     Returns
     ----------
     aggregated_statistics
@@ -401,7 +404,7 @@ def aggregate_statistics(statistics, measure="frequency", aggregation_measure=No
             elif measure == "performance":
                 if statistics[elem]["performance"]:
                     aggr_stat = aggregate_stats(statistics, elem, aggregation_measure)
-                    aggr_stat_hr = human_readable_stat(aggr_stat)
+                    aggr_stat_hr = human_readable_stat(aggr_stat, stat_locale)
                     arc_penwidth = get_arc_penwidth(aggr_stat, min_arc_performance, max_arc_performance)
                     aggregated_statistics[elem] = {"label": aggr_stat_hr, "penwidth": str(arc_penwidth)}
         elif type(elem) is PetriNet.Transition:
