@@ -14,14 +14,17 @@
     You should have received a copy of the GNU General Public License
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
-from typing import Dict, Union, List, Tuple
+from typing import Dict, Union, List, Tuple, Collection
 from typing import Set
+from collections import Counter
 
 import pandas as pd
 
+from pm4py.objects.ocel.obj import OCEL
 from pm4py.objects.log.obj import EventLog, Trace
-from pm4py.util.pandas_utils import check_is_pandas_dataframe, check_pandas_dataframe_columns
-from pm4py.utils import get_properties
+from pm4py.util.pandas_utils import check_is_pandas_dataframe, check_pandas_dataframe_columns, insert_ev_in_tr_index
+from pm4py.utils import get_properties, general_checks_classical_event_log
+from pm4py.util import xes_constants, constants
 from copy import copy
 import deprecation
 
@@ -40,6 +43,7 @@ def get_start_activities(log: Union[EventLog, pd.DataFrame]) -> Dict[str, int]:
     start_activities
         Dictionary of start activities along with their count
     """
+    general_checks_classical_event_log(log)
     if check_is_pandas_dataframe(log):
         check_pandas_dataframe_columns(log)
         from pm4py.statistics.start_activities.pandas import get
@@ -63,6 +67,7 @@ def get_end_activities(log: Union[EventLog, pd.DataFrame]) -> Dict[str, int]:
     end_activities
         Dictionary of end activities along with their count
     """
+    general_checks_classical_event_log(log)
     if check_is_pandas_dataframe(log):
         check_pandas_dataframe_columns(log)
         from pm4py.statistics.end_activities.pandas import get
@@ -91,6 +96,7 @@ def get_event_attributes(log: Union[EventLog, pd.DataFrame]) -> List[str]:
     attributes_list
         List of attributes contained in the log
     """
+    general_checks_classical_event_log(log)
     if check_is_pandas_dataframe(log):
         check_pandas_dataframe_columns(log)
         return list(log.columns)
@@ -113,6 +119,7 @@ def get_trace_attributes(log: Union[EventLog, pd.DataFrame]) -> List[str]:
     trace_attributes_list
         List of attributes at the trace level
     """
+    general_checks_classical_event_log(log)
     from pm4py.util import constants
     if check_is_pandas_dataframe(log):
         check_pandas_dataframe_columns(log)
@@ -146,6 +153,7 @@ def get_event_attribute_values(log: Union[EventLog, pd.DataFrame], attribute: st
     attribute_values
         Dictionary of values along with their count
     """
+    general_checks_classical_event_log(log)
     parameters = get_properties(log)
     parameters["keep_once_per_case"] = count_once_per_case
     if check_is_pandas_dataframe(log):
@@ -173,6 +181,7 @@ def get_trace_attribute_values(log: Union[EventLog, pd.DataFrame], attribute: st
     attribute_values
         Dictionary of values along with their count
     """
+    general_checks_classical_event_log(log)
     if check_is_pandas_dataframe(log):
         check_pandas_dataframe_columns(log)
         from pm4py.statistics.attributes.pandas import get
@@ -196,6 +205,7 @@ def get_variants(log: Union[EventLog, pd.DataFrame]) -> Dict[str, List[Trace]]:
     variants
         Dictionary of variants along with their count
     """
+    general_checks_classical_event_log(log)
     import pm4py
     if pm4py.util.variants_util.VARIANT_SPECIFICATION == pm4py.util.variants_util.VariantsSpecifications.STRING:
         import warnings
@@ -226,6 +236,7 @@ def get_variants_as_tuples(log: Union[EventLog, pd.DataFrame]) -> Dict[Tuple[str
     variants
         Dictionary of variants along with their count
     """
+    general_checks_classical_event_log(log)
     import pm4py
     # the behavior of PM4Py is changed to allow this to work
     pm4py.util.variants_util.VARIANT_SPECIFICATION = pm4py.util.variants_util.VariantsSpecifications.LIST
@@ -253,6 +264,7 @@ def get_minimum_self_distances(log: EventLog) -> Dict[str, int]:
     -------
         dict mapping an activity to its self-distance, if it exists, otherwise it is not part of the dict.
     '''
+    general_checks_classical_event_log(log)
     from pm4py.algo.discovery.minimum_self_distance import algorithm as msd_algo
     return msd_algo.apply(log, parameters=get_properties(log))
 
@@ -276,6 +288,7 @@ def get_minimum_self_distance_witnesses(log: EventLog) -> Dict[str, Set[str]]:
         Dictionary mapping each activity to a set of witnesses.
 
         '''
+    general_checks_classical_event_log(log)
     from pm4py.algo.discovery.minimum_self_distance import algorithm as msd_algo
     from pm4py.algo.discovery.minimum_self_distance import utils as msdw_algo
     return msdw_algo.derive_msd_witnesses(log, msd_algo.apply(log, parameters=get_properties(log)), parameters=get_properties(log))
@@ -295,6 +308,7 @@ def get_case_arrival_average(log: Union[EventLog, pd.DataFrame]) -> float:
     case_arrival_average
         Average difference between the start times of two consecutive cases
     """
+    general_checks_classical_event_log(log)
     if check_is_pandas_dataframe(log):
         check_pandas_dataframe_columns(log)
         from pm4py.statistics.traces.generic.pandas import case_arrival
@@ -322,6 +336,7 @@ def get_rework_cases_per_activity(log: Union[EventLog, pd.DataFrame]) -> Dict[st
         Dictionary associating to each of the aforementioned activities the number of cases for which the rework
         occurred.
     """
+    general_checks_classical_event_log(log)
     if check_is_pandas_dataframe(log):
         check_pandas_dataframe_columns(log)
         from pm4py.statistics.rework.pandas import get as rework_get
@@ -346,6 +361,7 @@ def get_case_overlap(log: Union[EventLog, pd.DataFrame]) -> List[int]:
         List that for each case (identified by its index in the log) tells how many other cases
         are concurrently open.
     """
+    general_checks_classical_event_log(log)
     if check_is_pandas_dataframe(log):
         check_pandas_dataframe_columns(log)
         from pm4py.statistics.overlap.cases.pandas import get as cases_overlap
@@ -380,6 +396,7 @@ def get_cycle_time(log: Union[EventLog, pd.DataFrame]) -> float:
     cycle_time
         Cycle time (calculated with the aforementioned formula).
     """
+    general_checks_classical_event_log(log)
     if check_is_pandas_dataframe(log):
         check_pandas_dataframe_columns(log)
         from pm4py.statistics.traces.cycle_time.pandas import get as cycle_time
@@ -389,7 +406,7 @@ def get_cycle_time(log: Union[EventLog, pd.DataFrame]) -> float:
         return cycle_time.apply(log, parameters=get_properties(log))
 
 
-def get_all_case_durations(log: Union[EventLog, pd.DataFrame]) -> List[float]:
+def get_all_case_durations(log: Union[EventLog, pd.DataFrame], business_hours: bool = False, worktiming: List[int] = [7, 17], weekends: List[int] = [6, 7]) -> List[float]:
     """
     Gets the durations of the cases in the event log
 
@@ -397,23 +414,34 @@ def get_all_case_durations(log: Union[EventLog, pd.DataFrame]) -> List[float]:
     ---------------
     log
         Event log
+    business_hours
+        Enables/disables the computation based on the business hours (default: False)
+    worktiming
+        (If the business hours are enabled) The hour range in which the resources of the log are working (default: 7 to 17)
+    weekends
+        (If the business hours are enabled) The weekends days (default: Saturday (6), Sunday (7))
 
     Returns
     ---------------
     durations
         Case durations (as list)
     """
+    general_checks_classical_event_log(log)
+    properties = copy(get_properties(log))
+    properties["business_hours"] = business_hours
+    properties["worktiming"] = worktiming
+    properties["weekends"] = weekends
     if check_is_pandas_dataframe(log):
         check_pandas_dataframe_columns(log)
         from pm4py.statistics.traces.generic.pandas import case_statistics
-        cd = case_statistics.get_cases_description(log, parameters=get_properties(log))
+        cd = case_statistics.get_cases_description(log, parameters=properties)
         return sorted([x["caseDuration"] for x in cd.values()])
     else:
         from pm4py.statistics.traces.generic.log import case_statistics
-        return case_statistics.get_all_casedurations(log, parameters=get_properties(log))
+        return case_statistics.get_all_case_durations(log, parameters=properties)
 
 
-def get_case_duration(log: Union[EventLog, pd.DataFrame], case_id: str) -> float:
+def get_case_duration(log: Union[EventLog, pd.DataFrame], case_id: str, business_hours: bool = False, worktiming: List[int] = [7, 17], weekends: List[int] = [6, 7]) -> float:
     """
     Gets the duration of a specific case
 
@@ -423,18 +451,70 @@ def get_case_duration(log: Union[EventLog, pd.DataFrame], case_id: str) -> float
         Event log
     case_id
         Case identifier
+    business_hours
+        Enables/disables the computation based on the business hours (default: False)
+    worktiming
+        (If the business hours are enabled) The hour range in which the resources of the log are working (default: 7 to 17)
+    weekends
+        (If the business hours are enabled) The weekends days (default: Saturday (6), Sunday (7))
 
     Returns
     ------------------
     duration
         Duration of the given case
     """
+    general_checks_classical_event_log(log)
+    properties = copy(get_properties(log))
+    properties["business_hours"] = business_hours
+    properties["worktiming"] = worktiming
+    properties["weekends"] = weekends
     if check_is_pandas_dataframe(log):
         check_pandas_dataframe_columns(log)
         from pm4py.statistics.traces.generic.pandas import case_statistics
-        cd = case_statistics.get_cases_description(log)
+        cd = case_statistics.get_cases_description(log, parameters=properties)
         return cd[case_id]["caseDuration"]
     else:
         from pm4py.statistics.traces.generic.log import case_statistics
-        cd = case_statistics.get_cases_description(log)
+        cd = case_statistics.get_cases_description(log, parameters=properties)
         return cd[case_id]["caseDuration"]
+
+
+def get_activity_position_summary(log: Union[EventLog, pd.DataFrame], activity: str) -> Dict[int, int]:
+    """
+    Given an event log, returns a dictionary which summarize the positions
+    of the activities in the different cases of the event log.
+    E.g., if an activity happens 1000 times in the position 1 (the second event of a case),
+    and 500 times in the position 2 (the third event of a case), then the returned dictionary would be:
+    {1: 1000, 2: 500}
+
+    Parameters
+    -----------------
+    log
+        Event log object / Pandas dataframe
+    activity
+        Activity to consider
+
+    Returns
+    -----------------
+    pos_dict_summary
+        Summary of the positions of the activity in the trace (e.g. {1: 1000, 2: 500})
+    """
+    general_checks_classical_event_log(log)
+    properties = get_properties(log)
+    activity_key = properties[
+        constants.PARAMETER_CONSTANT_ACTIVITY_KEY] if constants.PARAMETER_CONSTANT_ACTIVITY_KEY in properties else xes_constants.DEFAULT_NAME_KEY
+    case_id_key = properties[
+        constants.PARAMETER_CONSTANT_CASEID_KEY] if constants.PARAMETER_CONSTANT_CASEID_KEY in properties else constants.CASE_CONCEPT_NAME
+
+    if check_is_pandas_dataframe(log):
+        log = insert_ev_in_tr_index(log, case_id_key, "@@index_in_trace")
+        ret = log[log[activity_key] == activity]["@@index_in_trace"].value_counts().to_dict()
+        return ret
+    else:
+        ret = Counter()
+        for trace in log:
+            for i in range(len(trace)):
+                this_act = trace[i][activity_key]
+                if this_act == activity:
+                    ret[i] += 1
+        return dict(ret)
