@@ -17,7 +17,7 @@
 import os
 from copy import copy
 from typing import Optional
-from typing import Union, List
+from typing import Union, List, Dict, Any, Tuple
 
 import pandas as pd
 
@@ -27,7 +27,7 @@ from pm4py.objects.log.obj import EventLog
 from pm4py.objects.petri_net.obj import PetriNet, Marking
 from pm4py.objects.process_tree.obj import ProcessTree
 from pm4py.util.pandas_utils import check_is_pandas_dataframe, check_pandas_dataframe_columns
-from pm4py.utils import get_properties
+from pm4py.utils import get_properties, general_checks_classical_event_log
 
 
 def view_petri_net(petri_net: PetriNet, initial_marking: Optional[Marking] = None,
@@ -178,6 +178,8 @@ def save_vis_dfg(dfg: dict, start_activities: dict, end_activities: dict, file_p
     file_path
         Destination path
     """
+    if log is not None:
+        general_checks_classical_event_log(log)
     format = os.path.splitext(file_path)[1][1:]
     from pm4py.visualization.dfg import visualizer as dfg_visualizer
     dfg_parameters = dfg_visualizer.Variants.FREQUENCY.value.Parameters
@@ -309,6 +311,7 @@ def __dotted_attribute_selection(log, attributes):
     attributes
         List of attributes
     """
+    general_checks_classical_event_log(log)
     if attributes is None:
         from pm4py.util import xes_constants
         from pm4py.objects.log.util import sorting
@@ -341,6 +344,7 @@ def view_dotted_chart(log, format: str = "png", attributes=None):
         of the form [x-axis attribute, y-axis attribute, color attribute], e.g., ["concept:name", "org:resource", "concept:name"])
 
     """
+    general_checks_classical_event_log(log)
     log, attributes = __dotted_attribute_selection(log, attributes)
     from pm4py.visualization.dotted_chart import visualizer as dotted_chart_visualizer
     gviz = dotted_chart_visualizer.apply(log, attributes, parameters={"format": format})
@@ -360,6 +364,7 @@ def save_vis_dotted_chart(log, file_path: str, attributes=None):
     attributes
         Attributes that should be used to construct the dotted chart (for example, ["concept:name", "org:resource"])
     """
+    general_checks_classical_event_log(log)
     format = os.path.splitext(file_path)[1][1:]
     log, attributes = __dotted_attribute_selection(log, attributes)
     from pm4py.visualization.dotted_chart import visualizer as dotted_chart_visualizer
@@ -408,6 +413,7 @@ def view_case_duration_graph(log: Union[EventLog, pd.DataFrame], format: str = "
     format
         Format of the visualization (png, svg, ...)
     """
+    general_checks_classical_event_log(log)
     if check_is_pandas_dataframe(log):
         check_pandas_dataframe_columns(log)
         from pm4py.statistics.traces.generic.pandas import case_statistics
@@ -432,6 +438,7 @@ def save_vis_case_duration_graph(log: Union[EventLog, pd.DataFrame], file_path:
     file_path
         Destination path
     """
+    general_checks_classical_event_log(log)
     if check_is_pandas_dataframe(log):
         check_pandas_dataframe_columns(log)
         from pm4py.statistics.traces.generic.pandas import case_statistics
@@ -457,6 +464,7 @@ def view_events_per_time_graph(log: Union[EventLog, pd.DataFrame], format: str =
     format
         Format of the visualization (png, svg, ...)
     """
+    general_checks_classical_event_log(log)
     if check_is_pandas_dataframe(log):
         check_pandas_dataframe_columns(log)
         from pm4py.statistics.attributes.pandas import get as attributes_get
@@ -481,6 +489,7 @@ def save_vis_events_per_time_graph(log: Union[EventLog, pd.DataFrame], file_path
     file_path
         Destination path
     """
+    general_checks_classical_event_log(log)
     if check_is_pandas_dataframe(log):
         check_pandas_dataframe_columns(log)
         from pm4py.statistics.attributes.pandas import get as attributes_get
@@ -506,6 +515,7 @@ def view_performance_spectrum(log: Union[EventLog, pd.DataFrame], activities: Li
     format
         Format of the visualization (png, svg ...)
     """
+    general_checks_classical_event_log(log)
     from pm4py.algo.discovery.performance_spectrum import algorithm as performance_spectrum
     perf_spectrum = performance_spectrum.apply(log, activities, parameters=get_properties(log))
     from pm4py.visualization.performance_spectrum import visualizer as perf_spectrum_visualizer
@@ -527,6 +537,7 @@ def save_vis_performance_spectrum(log: Union[EventLog, pd.DataFrame], activities
     file_path
         Destination path (including the extension)
     """
+    general_checks_classical_event_log(log)
     from pm4py.algo.discovery.performance_spectrum import algorithm as performance_spectrum
     perf_spectrum = performance_spectrum.apply(log, activities, parameters=get_properties(log))
     from pm4py.visualization.performance_spectrum import visualizer as perf_spectrum_visualizer
@@ -540,6 +551,7 @@ def __builds_events_distribution_graph(log: Union[EventLog, pd.DataFrame], distr
     """
     Internal method to build the events distribution graph
     """
+    general_checks_classical_event_log(log)
     if distr_type == "days_month":
         title = "Distribution of the Events over the Days of a Month";
         x_axis = "Day of month";
@@ -592,6 +604,7 @@ def view_events_distribution_graph(log: Union[EventLog, pd.DataFrame], distr_typ
     format
         Format of the visualization (default: png)
     """
+    general_checks_classical_event_log(log)
     title, x_axis, y_axis, x, y = __builds_events_distribution_graph(log, distr_type)
     parameters = copy(get_properties(log))
     parameters["title"] = title;
@@ -622,6 +635,7 @@ def save_vis_events_distribution_graph(log: Union[EventLog, pd.DataFrame], file_
         - hours => Gets the distribution of the events among the hours of a day (from 0 to 23)
         - days_week => Gets the distribution of the events among the days of a week (from Monday to Sunday)
     """
+    general_checks_classical_event_log(log)
     format = os.path.splitext(file_path)[1][1:]
     title, x_axis, y_axis, x, y = __builds_events_distribution_graph(log, distr_type)
     parameters = copy(get_properties(log))
@@ -632,3 +646,182 @@ def save_vis_events_distribution_graph(log: Union[EventLog, pd.DataFrame], file_
     from pm4py.visualization.graphs import visualizer as graphs_visualizer
     gviz = graphs_visualizer.apply(x, y, variant=graphs_visualizer.Variants.BARPLOT, parameters=parameters)
     graphs_visualizer.save(gviz, file_path)
+
+
+def view_ocdfg(ocdfg: Dict[str, Any], annotation: str = "frequency", act_metric: str = "events", edge_metric="event_couples", act_threshold: int = 0, edge_threshold: int = 0, performance_aggregation: str = "mean", format: str = "png"):
+    """
+    Views an OC-DFG (object-centric directly-follows graph) with the provided configuration.
+
+    Parameters
+    ----------
+    ocdfg
+        Object-centric directly-follows graph
+    annotation
+        The annotation to use for the visualization. Values:
+            - "frequency": frequency annotation
+            - "performance": performance annotation
+    act_metric
+        The metric to use for the activities. Available values:
+            - "events" => number of events (default)
+            - "unique_objects" => number of unique objects
+            - "total_objects" => number of total objects
+    edge_metric
+        The metric to use for the edges. Available values:
+            - "event_couples" => number of event couples (default)
+            - "unique_objects" => number of unique objects
+            - "total_objects" => number of total objects
+    act_threshold
+        The threshold to apply on the activities frequency (default: 0). Only activities
+        having a frequency >= than this are kept in the graph.
+    edge_threshold
+        The threshold to apply on the edges frequency (default 0). Only edges
+        having a frequency >= than this are kept in the graph.
+    performance_aggregation
+        The aggregation measure to use for the performance: mean, median, min, max, sum
+    format
+        The format of the output visualization (default: "png")
+    """
+    from pm4py.visualization.ocel.ocdfg import visualizer
+    from pm4py.visualization.ocel.ocdfg.variants import classic
+    parameters = {}
+    parameters[classic.Parameters.FORMAT] = format
+    parameters[classic.Parameters.ANNOTATION] = annotation
+    parameters[classic.Parameters.ACT_METRIC] = act_metric
+    parameters[classic.Parameters.EDGE_METRIC] = edge_metric
+    parameters[classic.Parameters.ACT_THRESHOLD] = act_threshold
+    parameters[classic.Parameters.EDGE_THRESHOLD] = edge_threshold
+    parameters[classic.Parameters.PERFORMANCE_AGGREGATION_MEASURE] = performance_aggregation
+    gviz = classic.apply(ocdfg, parameters=parameters)
+    visualizer.view(gviz)
+
+
+def save_vis_ocdfg(ocdfg: Dict[str, Any], file_path: str, annotation: str = "frequency", act_metric: str = "events", edge_metric="event_couples", act_threshold: int = 0, edge_threshold: int = 0, performance_aggregation: str = "mean"):
+    """
+    Saves the visualization of an OC-DFG (object-centric directly-follows graph) with the provided configuration.
+
+    Parameters
+    ----------
+    ocdfg
+        Object-centric directly-follows graph
+    file_path
+        Destination path (including the extension)
+    annotation
+        The annotation to use for the visualization. Values:
+            - "frequency": frequency annotation
+            - "performance": performance annotation
+    act_metric
+        The metric to use for the activities. Available values:
+            - "events" => number of events (default)
+            - "unique_objects" => number of unique objects
+            - "total_objects" => number of total objects
+    edge_metric
+        The metric to use for the edges. Available values:
+            - "event_couples" => number of event couples (default)
+            - "unique_objects" => number of unique objects
+            - "total_objects" => number of total objects
+    act_threshold
+        The threshold to apply on the activities frequency (default: 0). Only activities
+        having a frequency >= than this are kept in the graph.
+    edge_threshold
+        The threshold to apply on the edges frequency (default 0). Only edges
+        having a frequency >= than this are kept in the graph.
+    performance_aggregation
+        The aggregation measure to use for the performance: mean, median, min, max, sum
+    """
+    format = os.path.splitext(file_path)[1][1:]
+    from pm4py.visualization.ocel.ocdfg import visualizer
+    from pm4py.visualization.ocel.ocdfg.variants import classic
+    parameters = {}
+    parameters[classic.Parameters.FORMAT] = format
+    parameters[classic.Parameters.ANNOTATION] = annotation
+    parameters[classic.Parameters.ACT_METRIC] = act_metric
+    parameters[classic.Parameters.EDGE_METRIC] = edge_metric
+    parameters[classic.Parameters.ACT_THRESHOLD] = act_threshold
+    parameters[classic.Parameters.EDGE_THRESHOLD] = edge_threshold
+    parameters[classic.Parameters.PERFORMANCE_AGGREGATION_MEASURE] = performance_aggregation
+    gviz = classic.apply(ocdfg, parameters=parameters)
+    visualizer.save(gviz, file_path)
+
+
+def view_ocpn(ocpn: Dict[str, Any], format: str = "png"):
+    """
+    Visualizes on the screen the object-centric Petri net
+
+    Parameters
+    --------------
+    ocpn
+        Object-centric Petri net
+    format
+        Format of the visualization (default: png)
+    """
+    from pm4py.visualization.ocel.ocpn import visualizer as ocpn_visualizer
+    gviz = ocpn_visualizer.apply(ocpn, parameters={"format": format})
+    ocpn_visualizer.view(gviz)
+
+
+def save_vis_ocpn(ocpn: Dict[str, Any], file_path: str):
+    """
+    Saves the visualization of the object-centric Petri net into a file
+
+    Parameters
+    ----------------
+    ocpn
+        Object-centric Petri net
+    file_path
+        Target path of the visualization
+    """
+    format = os.path.splitext(file_path)[1][1:]
+    from pm4py.visualization.ocel.ocpn import visualizer as ocpn_visualizer
+    gviz = ocpn_visualizer.apply(ocpn, parameters={"format": format})
+    ocpn_visualizer.save(gviz, file_path)
+
+
+def view_network_analysis(network_analysis: Dict[Tuple[str, str], Dict[str, Any]], variant: str = "frequency", format: str = "png", activity_threshold: int = 1, edge_threshold: int = 1):
+    """
+    Visualizes the network analysis
+
+    Parameters
+    -----------------
+    network_analysis
+        Network analysis
+    variant
+        Variant of the visualization:
+            - frequency (if the discovered network analysis contains the frequency of the interactions)
+            - performance (if the discovered network analysis contains the performance of the interactions)
+    format
+        Format of the visualization (default: png)
+    activity_threshold
+        The minimum number of occurrences for an activity to be included (default: 1)
+    edge_threshold
+        The minimum number of occurrences for an edge to be included (default: 1)
+    """
+    from pm4py.visualization.network_analysis import visualizer as network_analysis_visualizer
+    variant = network_analysis_visualizer.Variants.PERFORMANCE if variant == "performance" else network_analysis_visualizer.Variants.FREQUENCY
+    gviz = network_analysis_visualizer.apply(network_analysis, variant=variant, parameters={"format": format, "activity_threshold": activity_threshold, "edge_threshold": edge_threshold})
+    network_analysis_visualizer.view(gviz)
+
+
+def save_vis_network_analysis(network_analysis: Dict[Tuple[str, str], Dict[str, Any]], file_path: str, variant: str = "frequency", activity_threshold: int = 1, edge_threshold: int = 1):
+    """
+    Saves the visualization of the network analysis
+
+    Parameters
+    -----------------
+    network_analysis
+        Network analysis
+    file_path
+        Target path of the visualization
+    variant
+        Variant of the visualization:
+            - frequency (if the discovered network analysis contains the frequency of the interactions)
+            - performance (if the discovered network analysis contains the performance of the interactions)
+    activity_threshold
+        The minimum number of occurrences for an activity to be included (default: 1)
+    edge_threshold
+        The minimum number of occurrences for an edge to be included (default: 1)
+    """
+    format = os.path.splitext(file_path)[1][1:]
+    from pm4py.visualization.network_analysis import visualizer as network_analysis_visualizer
+    variant = network_analysis_visualizer.Variants.PERFORMANCE if variant == "performance" else network_analysis_visualizer.Variants.FREQUENCY
+    gviz = network_analysis_visualizer.apply(network_analysis, variant=variant, parameters={"format": format, "activity_threshold": activity_threshold, "edge_threshold": edge_threshold})
+    network_analysis_visualizer.save(gviz, file_path)
