@@ -20,6 +20,10 @@ from pm4py.visualization.common import save as gsave
 from pm4py.visualization.common.gview import serialize, serialize_dot
 from enum import Enum
 from pm4py.util import exec_utils
+from typing import Optional, Dict, Any, Union, Tuple
+from pm4py.objects.log.obj import EventLog, EventStream
+from pm4py.util import typing
+import graphviz
 
 
 class Variants(Enum):
@@ -29,7 +33,7 @@ class Variants(Enum):
 DEFAULT_VARIANT = Variants.CLASSIC
 
 
-def apply(log, aligned_traces, variant=DEFAULT_VARIANT, parameters=None):
+def apply(log: EventLog, aligned_traces: typing.ListAlignments, variant=DEFAULT_VARIANT, parameters: Optional[Dict[Any, Any]] = None) -> graphviz.Source:
     """
     Gets the alignment table visualization from the alignments output
 
@@ -53,7 +57,7 @@ def apply(log, aligned_traces, variant=DEFAULT_VARIANT, parameters=None):
     return exec_utils.get_variant(variant).apply(log, aligned_traces, parameters=parameters)
 
 
-def save(gviz, output_file_path):
+def save(gviz: graphviz.Digraph, output_file_path: str):
     """
     Save the diagram
 
@@ -67,7 +71,7 @@ def save(gviz, output_file_path):
     gsave.save(gviz, output_file_path)
 
 
-def view(gviz):
+def view(gviz: graphviz.Digraph):
     """
     View the diagram
 
@@ -79,7 +83,7 @@ def view(gviz):
     return gview.view(gviz)
 
 
-def matplotlib_view(gviz):
+def matplotlib_view(gviz: graphviz.Digraph):
     """
     Views the diagram using Matplotlib
 
