@@ -27,10 +27,7 @@ from pm4py.util import exec_utils
 from pm4py.statistics.sojourn_time.log import get as soj_time_get
 from enum import Enum
 from pm4py.util import constants
-from typing import Optional, Dict, Any, Union, Tuple
-from pm4py.objects.log.obj import EventLog, EventStream
-from pm4py.util import typing
-import graphviz
+from typing import Optional, Dict, Any, Tuple
 from pm4py.objects.log.obj import EventLog
 
 
@@ -44,6 +41,7 @@ class Parameters(Enum):
     START_TIMESTAMP_KEY = constants.PARAMETER_CONSTANT_START_TIMESTAMP_KEY
     FONT_SIZE = "font_size"
     BGCOLOR = "bgcolor"
+    STAT_LOCALE = "stat_locale"
 
 
 def get_min_max_value(dfg):
@@ -132,8 +130,9 @@ def get_activities_color(activities_count):
 
 
 def graphviz_visualization(activities_count, dfg, image_format="png", measure="frequency",
-                           max_no_of_edges_in_diagram=100000, start_activities=None, end_activities=None, soj_time=None,
-                            font_size="12", bgcolor="transparent"):
+                           max_no_of_edges_in_diagram=100000, start_activities=None, 
+                           end_activities=None, soj_time=None, font_size="12", 
+                           bgcolor="transparent", stat_locale: dict = None):
     """
     Do GraphViz visualization of a DFG graph
 
@@ -155,7 +154,9 @@ def graphviz_visualization(activities_count, dfg, image_format="png", measure="f
         End activities of the log
     soj_time
         For each activity, the sojourn time in the log
-
+    stat_locale
+        Dict to locale the stat strings
+    
     Returns
     -----------
     viz
@@ -165,6 +166,8 @@ def graphviz_visualization(activities_count, dfg, image_format="png", measure="f
         start_activities = {}
     if end_activities is None:
         end_activities = {}
+    if stat_locale is None:
+        stat_locale = {}
 
     filename = tempfile.NamedTemporaryFile(suffix='.gv')
     viz = Digraph("", filename=filename.name, engine='dot', graph_attr={'bgcolor': bgcolor})
@@ -212,7 +215,8 @@ def graphviz_visualization(activities_count, dfg, image_format="png", measure="f
                      fillcolor=activities_color[act], fontsize=font_size)
             activities_map[act] = str(hash(act))
         else:
-            viz.node(str(hash(act)), act + " (" + human_readable_stat(soj_time[act]) + ")", fontsize=font_size)
+            stat_string = human_readable_stat(soj_time[act], stat_locale)
+            viz.node(str(hash(act)), act + f" ({stat_string})", fontsize=font_size)
             activities_map[act] = str(hash(act))
 
     # make edges addition always in the same order
@@ -223,20 +227,21 @@ def graphviz_visualization(activities_count, dfg, image_format="png", measure="f
         if "frequency" in measure:
             label = str(dfg[edge])
         else:
-            label = human_readable_stat(dfg[edge])
+            label = human_readable_stat(dfg[edge], stat_locale)
         viz.edge(str(hash(edge[0])), str(hash(edge[1])), label=label, penwidth=str(penwidth[edge]), fontsize=font_size)
 
     start_activities_to_include = [act for act in start_activities if act in activities_map]
     end_activities_to_include = [act for act in end_activities if act in activities_map]
 
     if start_activities_to_include:
-        viz.node("@@startnode", "@@S", style='filled', shape='circle', fillcolor="#32CD32", fontcolor="#32CD32")
+        viz.node("@@startnode", "<&#9679;>", shape='circle', fontsize="34")
         for act in start_activities_to_include:
             label = str(start_activities[act]) if isinstance(start_activities, dict) else ""
             viz.edge("@@startnode", activities_map[act], label=label, fontsize=font_size)
 
     if end_activities_to_include:
-        viz.node("@@endnode", "@@E", style='filled', shape='circle', fillcolor="#FFA500", fontcolor="#FFA500")
+        # <&#9632;>
+        viz.node("@@endnode", "<&#9632;>", shape='doublecircle', fontsize="32")
         for act in end_activities_to_include:
             label = str(end_activities[act]) if isinstance(end_activities, dict) else ""
             viz.edge(activities_map[act], "@@endnode", label=label, fontsize=font_size)
@@ -248,7 +253,7 @@ def graphviz_visualization(activities_count, dfg, image_format="png", measure="f
     return viz
 
 
-def apply(dfg: Dict[Tuple[str, str], int], log: EventLog = None, parameters: Optional[Dict[Any, Any]] = None, activities_count : Dict[str, int] = None, soj_time: Dict[str, float] = None) -> graphviz.Digraph:
+def apply(dfg: Dict[Tuple[str, str], int], log: EventLog = None, parameters: Optional[Dict[Any, Any]] = None, activities_count : Dict[str, int] = None, soj_time: Dict[str, float] = None) -> Digraph:
     """
     Visualize a frequency directly-follows graph
 
@@ -276,18 +281,30 @@ def apply(dfg: Dict[Tuple[str, str], int], log: EventLog = None, parameters: Opt
     activity_key = exec_utils.get_param_value(Parameters.ACTIVITY_KEY, parameters, xes.DEFAULT_NAME_KEY)
     image_format = exec_utils.get_param_value(Parameters.FORMAT, parameters, "png")
     max_no_of_edges_in_diagram = exec_utils.get_param_value(Parameters.MAX_NO_EDGES_IN_DIAGRAM, parameters, 100000)
-    start_activities = exec_utils.get_param_value(Parameters.START_ACTIVITIES, parameters, [])
-    end_activities = exec_utils.get_param_value(Parameters.END_ACTIVITIES, parameters, [])
+    start_activities = exec_utils.get_param_value(Parameters.START_ACTIVITIES, parameters, {})
+    end_activities = exec_utils.get_param_value(Parameters.END_ACTIVITIES, parameters, {})
     font_size = exec_utils.get_param_value(Parameters.FONT_SIZE, parameters, 12)
     font_size = str(font_size)
     activities = dfg_utils.get_activities_from_dfg(dfg)
     bgcolor = exec_utils.get_param_value(Parameters.BGCOLOR, parameters, "transparent")
+    stat_locale = exec_utils.get_param_value(Parameters.STAT_LOCALE, parameters, None)
+    if stat_locale is None:
+        stat_locale = {}
 
     if activities_count is None:
         if log is not None:
             activities_count = attr_get.get_attribute_values(log, activity_key, parameters=parameters)
         else:
-            activities_count = {key: 1 for key in activities}
+            # 11/09/2021: if we have the specification of the start activities,
+            # we can compute the activities count without the log in a smarter way.
+            if type(start_activities) is dict and start_activities:
+                activities_count = {key: 0 for key in set(activities).union(set(start_activities))}
+                for act in start_activities:
+                    activities_count[act] += start_activities[act]
+                for el in dfg:
+                    activities_count[el[1]] += dfg[el]
+            else:
+                activities_count = {key: 1 for key in activities}
 
     if soj_time is None:
         if log is not None:
@@ -297,5 +314,5 @@ def apply(dfg: Dict[Tuple[str, str], int], log: EventLog = None, parameters: Opt
 
     return graphviz_visualization(activities_count, dfg, image_format=image_format, measure="frequency",
                                   max_no_of_edges_in_diagram=max_no_of_edges_in_diagram,
-                                  start_activities=start_activities, end_activities=end_activities, soj_time=soj_time,
-                                  font_size=font_size, bgcolor=bgcolor)
+                                  start_activities=start_activities, end_activities=end_activities, 
+                                  soj_time=soj_time, font_size=font_size, bgcolor=bgcolor, stat_locale=stat_locale)
