@@ -25,13 +25,10 @@ from pm4py.util import xes_constants as xes
 from pm4py.visualization.common.utils import *
 from pm4py.util import exec_utils
 from pm4py.statistics.sojourn_time.log import get as soj_time_get
-from enum import Enum
 from pm4py.util import constants
+from enum import Enum
 
-from typing import Optional, Dict, Any, Union, Tuple
-from pm4py.objects.log.obj import EventLog, EventStream
-from pm4py.util import typing
-import graphviz
+from typing import Optional, Dict, Any, Tuple
 from pm4py.objects.log.obj import EventLog
 
 
@@ -46,7 +43,7 @@ class Parameters(Enum):
     FONT_SIZE = "font_size"
     AGGREGATION_MEASURE = "aggregation_measure"
     BGCOLOR = "bgcolor"
-
+    STAT_LOCALE = "stat_locale"
 
 def get_min_max_value(dfg):
     """
@@ -130,10 +127,45 @@ def get_activities_color_soj_time(soj_time):
 
     return activities_color
 
+def get_edges_color(duration_list: list) -> str:
+    """
+    Gets the color for the activities based on the sojourn time
+
+    Parameters
+    ----------------
+    soj_time
+        Sojourn time
+
+    Returns
+    ----------------
+    act_color
+        Dictionary associating each activity to a color based on the sojourn time
+    """
+    LIGHTEST_COLOR = 55
+    edges_color = {}
+
+    min_time, max_time = get_min_max_value(duration_list)
+    min_color = 255 - LIGHTEST_COLOR
+
+    for ac in duration_list:
+        current_time = duration_list[ac]
+
+        trans_base_color = int(min_color - 
+            min_color * (current_time - min_time) / 
+                (max_time - min_time + 0.00001))
+        trans_base_color_hex = str(hex(trans_base_color))[2:].upper()
+
+        if len(trans_base_color_hex) == 1:
+            trans_base_color_hex = "0" + trans_base_color_hex
+
+        edges_color[ac] = "#" + 3 * trans_base_color_hex
+
+    return edges_color
 
 def graphviz_visualization(activities_count, dfg, image_format="png", measure="frequency",
-                           max_no_of_edges_in_diagram=100000, start_activities=None, end_activities=None, soj_time=None,
-                           font_size="12", bgcolor="transparent"):
+                           max_no_of_edges_in_diagram=100000, start_activities=None, 
+                           end_activities=None, soj_time=None, font_size="12", 
+                           bgcolor="transparent", stat_locale: dict = None):
     """
     Do GraphViz visualization of a DFG graph
 
@@ -146,7 +178,7 @@ def graphviz_visualization(activities_count, dfg, image_format="png", measure="f
     image_format
         GraphViz should be represented in this format
     measure
-        Describes which measure is assigned to edges in direcly follows graph (frequency/performance)
+        Describes which measure is assigned to edges in directly follows graph (frequency/performance)
     max_no_of_edges_in_diagram
         Maximum number of edges in the diagram allowed for visualization
     start_activities
@@ -155,7 +187,9 @@ def graphviz_visualization(activities_count, dfg, image_format="png", measure="f
         End activities of the log
     soj_time
         For each activity, the sojourn time in the log
-
+    stat_locale
+        Dict to locale the stat strings
+    
     Returns
     -----------
     viz
@@ -165,6 +199,8 @@ def graphviz_visualization(activities_count, dfg, image_format="png", measure="f
         start_activities = []
     if end_activities is None:
         end_activities = []
+    if stat_locale is None:
+        stat_locale = {}
 
     filename = tempfile.NamedTemporaryFile(suffix='.gv')
     viz = Digraph("", filename=filename.name, engine='dot', graph_attr={'bgcolor': bgcolor})
@@ -194,6 +230,7 @@ def graphviz_visualization(activities_count, dfg, image_format="png", measure="f
 
     # assign attributes color
     activities_color = get_activities_color_soj_time(soj_time)
+    edges_color = get_edges_color(dfg)
 
     # represent nodes
     viz.attr('node', shape='box')
@@ -212,7 +249,11 @@ def graphviz_visualization(activities_count, dfg, image_format="png", measure="f
                      fillcolor=activities_color[act], fontsize=font_size)
             activities_map[act] = str(hash(act))
         else:
-            viz.node(str(hash(act)), act + " (" + human_readable_stat(soj_time[act]) + ")", fontsize=font_size,
+            node_label = act
+            if soj_time[act] > -1:
+                stat_string = human_readable_stat(soj_time[act])
+                node_label = f"{act} ({stat_string})"
+            viz.node(str(hash(act)), node_label, fontsize=font_size,
                      style='filled', fillcolor=activities_color[act])
             activities_map[act] = str(hash(act))
 
@@ -224,21 +265,26 @@ def graphviz_visualization(activities_count, dfg, image_format="png", measure="f
         if "frequency" in measure:
             label = str(dfg[edge])
         else:
-            label = human_readable_stat(dfg[edge])
-        viz.edge(str(hash(edge[0])), str(hash(edge[1])), label=label, penwidth=str(penwidth[edge]), fontsize=font_size)
+            label = human_readable_stat(dfg[edge], stat_locale)
+        viz.edge(str(hash(edge[0])), str(hash(edge[1])), label=label, 
+                 color=edges_color[edge], style = "bold",
+                 penwidth=str(penwidth[edge]), fontsize=font_size)
 
     start_activities_to_include = [act for act in start_activities if act in activities_map]
     end_activities_to_include = [act for act in end_activities if act in activities_map]
 
     if start_activities_to_include:
-        viz.node("@@startnode", "@@S", style='filled', shape='circle', fillcolor="#32CD32", fontcolor="#32CD32")
+        viz.node("@@startnode", "<&#9679;>", shape='circle', fontsize="34")
         for act in start_activities_to_include:
-            viz.edge("@@startnode", activities_map[act], fontsize=font_size)
+            label = str(start_activities[act]) if isinstance(start_activities, dict) else ""
+            viz.edge("@@startnode", activities_map[act], label=label, fontsize=font_size)
 
     if end_activities_to_include:
-        viz.node("@@endnode", "@@E", style='filled', shape='circle', fillcolor="#FFA500", fontcolor="#FFA500")
+        # <&#9632;>
+        viz.node("@@endnode", "<&#9632;>", shape='doublecircle', fontsize="32")
         for act in end_activities_to_include:
-            viz.edge(activities_map[act], "@@endnode", fontsize=font_size)
+            label = str(end_activities[act]) if isinstance(end_activities, dict) else ""
+            viz.edge(activities_map[act], "@@endnode", label=label, fontsize=font_size)
 
     viz.attr(overlap='false')
     viz.attr(fontsize='11')
@@ -248,7 +294,7 @@ def graphviz_visualization(activities_count, dfg, image_format="png", measure="f
     return viz
 
 
-def apply(dfg: Dict[Tuple[str, str], int], log: EventLog = None, parameters: Optional[Dict[Any, Any]] = None, activities_count : Dict[str, int] = None, soj_time: Dict[str, float] = None) -> graphviz.Digraph:
+def apply(dfg: Dict[Tuple[str, str], int], log: EventLog = None, parameters: Optional[Dict[Any, Any]] = None, activities_count : Dict[str, int] = None, soj_time: Dict[str, float] = None) -> Digraph:
     """
     Visualize a performance directly-follows graph
 
@@ -283,6 +329,10 @@ def apply(dfg: Dict[Tuple[str, str], int], log: EventLog = None, parameters: Opt
     activities = dfg_utils.get_activities_from_dfg(dfg)
     aggregation_measure = exec_utils.get_param_value(Parameters.AGGREGATION_MEASURE, parameters, "mean")
     bgcolor = exec_utils.get_param_value(Parameters.BGCOLOR, parameters, "transparent")
+    stat_locale = exec_utils.get_param_value(Parameters.STAT_LOCALE, parameters, None)
+
+    if stat_locale is None:
+        stat_locale = {}
 
     if activities_count is None:
         if log is not None:
@@ -294,7 +344,7 @@ def apply(dfg: Dict[Tuple[str, str], int], log: EventLog = None, parameters: Opt
         if log is not None:
             soj_time = soj_time_get.apply(log, parameters=parameters)
         else:
-            soj_time = {key: 0 for key in activities}
+            soj_time = {key: -1 for key in activities}
 
     # if all the aggregation measures are provided for a given key,
     # then pick one of the values for the representation
@@ -311,5 +361,6 @@ def apply(dfg: Dict[Tuple[str, str], int], log: EventLog = None, parameters: Opt
 
     return graphviz_visualization(activities_count, dfg, image_format=image_format, measure="performance",
                                   max_no_of_edges_in_diagram=max_no_of_edges_in_diagram,
-                                  start_activities=start_activities, end_activities=end_activities, soj_time=soj_time,
-                                  font_size=font_size, bgcolor=bgcolor)
+                                  start_activities=start_activities, end_activities=end_activities, 
+                                  soj_time=soj_time, font_size=font_size, bgcolor=bgcolor, 
+                                  stat_locale=stat_locale)
